@@ -1,6 +1,6 @@
 import logging
 from typing import List, Callable, Dict, Any, Type, Tuple
-
+import tensorflow as tf
 from tensorflow.keras.layers import BatchNormalization, Concatenate, Layer, Permute, LayerNormalization, Reshape, \
     MultiHeadAttention
 from tensorflow.keras.layers.experimental import SyncBatchNormalization
@@ -26,7 +26,8 @@ layer_to_config_handlers: Dict[Type[Layer], List[HandlerType]] = {
 }
 
 
-def convert_layer(current_layer: Layer, target_data_format: str, input_shape: List[int], transform_signal: bool) \
+def convert_layer(current_layer: Layer, target_data_format: str, input_shape: List[int], transform_signal: bool,
+                  custom_layers: Dict[str, Type[tf.keras.layers.Layer]]) \
         -> Tuple[Layer, bool]:
     logger = logging.getLogger(__name__)
     config = current_layer.get_config()
@@ -47,7 +48,7 @@ def convert_layer(current_layer: Layer, target_data_format: str, input_shape: Li
 
     converted_layer = type(current_layer).from_config(config)
     is_built = True
-    if isinstance(current_layer, MultiHeadAttention):
+    if isinstance(current_layer, MultiHeadAttention) or isinstance(current_layer, tuple(custom_layers.values())):
         is_built = False
         return converted_layer, is_built
 
